@@ -35,7 +35,7 @@ struct btrfs_send_stream {
 
 	/*
 	 * end of last successful read, equivalent to start of current
-	 * malformated part of block
+	 * malformed part of block
 	 */
 	size_t stream_pos;
 
@@ -61,8 +61,7 @@ static int read_buf(struct btrfs_send_stream *sctx, char *buf, size_t len)
 		rbytes = read(sctx->fd, buf + pos, len - pos);
 		if (rbytes < 0) {
 			ret = -errno;
-			error("read from stream failed: %s",
-					strerror(-ret));
+			error("read from stream failed: %m");
 			goto out;
 		}
 		if (rbytes == 0) {
